/**
 * Copyright (c) 2001/2003 Distributed Systems Research Group.
 * All rights reserved.
 *
 * For more information on Distributed Systems Research Group (DSRG),
 * please see <http://www.ics.agh.edu.pl/>.
 *
 * @author radzisz
 * file name: SimpleClient.java
 *
 */

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;

import suncertify.common.ClientNotLoggedInException;
import suncertify.common.QueryInterface;
import suncertify.common.QueryInterfaceImpl;
import suncertify.db.RecordNotFoundException;

public class SimpleClient {
	String url;
	String login;
	QueryInterface query;

	SimpleClient() throws NotBoundException, MalformedURLException, RemoteException {
		//remote version
		try {
			//get url according to the properties
			url = QueryInterfaceImpl.createObjectURL("localhost", 4328);
			//lookup the object		
			Object obj = Naming.lookup(url);
			//bind
			query = (QueryInterface) obj;
			//according to the properties
			login = query.logIn();

		} catch (NotBoundException e) {
			log("DataBase connect error - NotBoundException" + e);
			throw e;
		} catch (MalformedURLException e) {
			log("DataBase connect error - MalformedURLException" + e);
			throw e;
		} catch (RemoteException e) {
			log("DataBase connect error - RemoteException" + e);
			throw e;
		}

	}

	public void testDBConnection() {
	
		for (int i=1; i<20; i++)
		{
			try {
				printRecord(query.read(i, login));
			} catch (RecordNotFoundException e) {
				e.printStackTrace();
			} catch (ClientNotLoggedInException e) {
				e.printStackTrace();
			} catch (RemoteException e) {
				e.printStackTrace();
			}		
		}

	}

	public static void main(String[] a) {
		SimpleClient test;
		try {
			test = new SimpleClient();
			test.testDBConnection();
		} catch (MalformedURLException e) {
			e.printStackTrace();
		} catch (RemoteException e) {
			e.printStackTrace();
		} catch (NotBoundException e) {
			e.printStackTrace();
		}
	}

	private void log(String text) {
		System.out.println(text);
	}
	
	
	private void printRecord(String[] data) {
		StringBuffer text = new StringBuffer();
		for(int i=0;i<data.length; i++)
		  text.append(text + data[i] + ", ");
		  
		log(text.toString());  
	}

}
